embassy-stm32

Crates

git

Versions

stm32c593me

Flavors

Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 149 fields pub PA0: Peri<'static, PA0>, pub PA1: Peri<'static, PA1>, pub PA2: Peri<'static, PA2>, pub PA3: Peri<'static, PA3>, pub PA4: Peri<'static, PA4>, pub PA5: Peri<'static, PA5>, pub PA6: Peri<'static, PA6>, pub PA7: Peri<'static, PA7>, pub PA8: Peri<'static, PA8>, pub PA9: Peri<'static, PA9>, pub PA10: Peri<'static, PA10>, pub PA11: Peri<'static, PA11>, pub PA12: Peri<'static, PA12>, pub PA13: Peri<'static, PA13>, pub PA14: Peri<'static, PA14>, pub PA15: Peri<'static, PA15>, pub PB0: Peri<'static, PB0>, pub PB1: Peri<'static, PB1>, pub PB2: Peri<'static, PB2>, pub PB3: Peri<'static, PB3>, pub PB4: Peri<'static, PB4>, pub PB5: Peri<'static, PB5>, pub PB6: Peri<'static, PB6>, pub PB7: Peri<'static, PB7>, pub PB8: Peri<'static, PB8>, pub PB9: Peri<'static, PB9>, pub PB10: Peri<'static, PB10>, pub PB12: Peri<'static, PB12>, pub PB13: Peri<'static, PB13>, pub PB14: Peri<'static, PB14>, pub PB15: Peri<'static, PB15>, pub PC0: Peri<'static, PC0>, pub PC1: Peri<'static, PC1>, pub PC2: Peri<'static, PC2>, pub PC3: Peri<'static, PC3>, pub PC4: Peri<'static, PC4>, pub PC5: Peri<'static, PC5>, pub PC6: Peri<'static, PC6>, pub PC7: Peri<'static, PC7>, pub PC8: Peri<'static, PC8>, pub PC9: Peri<'static, PC9>, pub PC10: Peri<'static, PC10>, pub PC11: Peri<'static, PC11>, pub PC12: Peri<'static, PC12>, pub PC13: Peri<'static, PC13>, pub PC14: Peri<'static, PC14>, pub PC15: Peri<'static, PC15>, pub PD0: Peri<'static, PD0>, pub PD1: Peri<'static, PD1>, pub PD2: Peri<'static, PD2>, pub PD12: Peri<'static, PD12>, pub PD13: Peri<'static, PD13>, pub PD14: Peri<'static, PD14>, pub PD15: Peri<'static, PD15>, pub PE0: Peri<'static, PE0>, pub PE1: Peri<'static, PE1>, pub PE2: Peri<'static, PE2>, pub PE3: Peri<'static, PE3>, pub PE7: Peri<'static, PE7>, pub PE8: Peri<'static, PE8>, pub PE9: Peri<'static, PE9>, pub PE10: Peri<'static, PE10>, pub PH0: Peri<'static, PH0>, pub PH1: Peri<'static, PH1>, pub PH2: Peri<'static, PH2>, pub PH5: Peri<'static, PH5>, pub ADC1: Peri<'static, ADC1>, pub ADC12_COMMON: Peri<'static, ADC12_COMMON>, pub ADC2: Peri<'static, ADC2>, pub ADC3: Peri<'static, ADC3>, pub ADC3_COMMON: Peri<'static, ADC3_COMMON>, pub CORDIC: Peri<'static, CORDIC>, pub DBGMCU: Peri<'static, DBGMCU>, pub ETH1: Peri<'static, ETH1>, pub ETH_SMA: Peri<'static, ETH_SMA>, pub FDCAN1: Peri<'static, FDCAN1>, pub FDCAN2: Peri<'static, FDCAN2>, pub FDCANRAM: Peri<'static, FDCANRAM>, pub FDCANRAM1: Peri<'static, FDCANRAM1>, pub FDCANRAM2: Peri<'static, FDCANRAM2>, pub FLASH: Peri<'static, FLASH>, pub I2C1: Peri<'static, I2C1>, pub I2C2: Peri<'static, I2C2>, pub I3C1: Peri<'static, I3C1>, pub LPDMA1: Peri<'static, LPDMA1>, pub LPDMA2: Peri<'static, LPDMA2>, pub LPUART1: Peri<'static, LPUART1>, pub PWR: Peri<'static, PWR>, pub MCO1: Peri<'static, MCO1>, pub MCO2: Peri<'static, MCO2>, pub RCC: Peri<'static, RCC>, pub RNG: Peri<'static, RNG>, pub SPI1: Peri<'static, SPI1>, pub SPI2: Peri<'static, SPI2>, pub SPI3: Peri<'static, SPI3>, pub SYSCFG: Peri<'static, SYSCFG>, pub TIM1: Peri<'static, TIM1>, pub TIM15: Peri<'static, TIM15>, pub TIM16: Peri<'static, TIM16>, pub TIM17: Peri<'static, TIM17>, pub TIM2: Peri<'static, TIM2>, pub TIM3: Peri<'static, TIM3>, pub TIM4: Peri<'static, TIM4>, pub TIM5: Peri<'static, TIM5>, pub TIM6: Peri<'static, TIM6>, pub TIM7: Peri<'static, TIM7>, pub TIM8: Peri<'static, TIM8>, pub UART4: Peri<'static, UART4>, pub UART5: Peri<'static, UART5>, pub UART7: Peri<'static, UART7>, pub UID: Peri<'static, UID>, pub USART1: Peri<'static, USART1>, pub USART2: Peri<'static, USART2>, pub USART3: Peri<'static, USART3>, pub USART6: Peri<'static, USART6>, pub USB: Peri<'static, USB>, pub USBRAM: Peri<'static, USBRAM>, pub EXTI0: Peri<'static, EXTI0>, pub EXTI1: Peri<'static, EXTI1>, pub EXTI2: Peri<'static, EXTI2>, pub EXTI3: Peri<'static, EXTI3>, pub EXTI4: Peri<'static, EXTI4>, pub EXTI5: Peri<'static, EXTI5>, pub EXTI6: Peri<'static, EXTI6>, pub EXTI7: Peri<'static, EXTI7>, pub EXTI8: Peri<'static, EXTI8>, pub EXTI9: Peri<'static, EXTI9>, pub EXTI10: Peri<'static, EXTI10>, pub EXTI11: Peri<'static, EXTI11>, pub EXTI12: Peri<'static, EXTI12>, pub EXTI13: Peri<'static, EXTI13>, pub EXTI14: Peri<'static, EXTI14>, pub EXTI15: Peri<'static, EXTI15>, pub LPDMA1_CH0: Peri<'static, LPDMA1_CH0>, pub LPDMA1_CH1: Peri<'static, LPDMA1_CH1>, pub LPDMA1_CH2: Peri<'static, LPDMA1_CH2>, pub LPDMA1_CH3: Peri<'static, LPDMA1_CH3>, pub LPDMA1_CH4: Peri<'static, LPDMA1_CH4>, pub LPDMA1_CH5: Peri<'static, LPDMA1_CH5>, pub LPDMA1_CH6: Peri<'static, LPDMA1_CH6>, pub LPDMA1_CH7: Peri<'static, LPDMA1_CH7>, pub LPDMA2_CH0: Peri<'static, LPDMA2_CH0>, pub LPDMA2_CH1: Peri<'static, LPDMA2_CH1>, pub LPDMA2_CH2: Peri<'static, LPDMA2_CH2>, pub LPDMA2_CH3: Peri<'static, LPDMA2_CH3>, pub LPDMA2_CH4: Peri<'static, LPDMA2_CH4>, pub LPDMA2_CH5: Peri<'static, LPDMA2_CH5>, pub LPDMA2_CH6: Peri<'static, LPDMA2_CH6>, pub LPDMA2_CH7: Peri<'static, LPDMA2_CH7>,
}
Struct containing all the peripheral singletons.

To obtain the peripherals, you must initialize the HAL, by calling crate::init.

Fields

PA0: Peri<'static, PA0>

PA0 peripheral

PA1: Peri<'static, PA1>

PA1 peripheral

PA2: Peri<'static, PA2>

PA2 peripheral

PA3: Peri<'static, PA3>

PA3 peripheral

PA4: Peri<'static, PA4>

PA4 peripheral

PA5: Peri<'static, PA5>

PA5 peripheral

PA6: Peri<'static, PA6>

PA6 peripheral

PA7: Peri<'static, PA7>

PA7 peripheral

PA8: Peri<'static, PA8>

PA8 peripheral

PA9: Peri<'static, PA9>

PA9 peripheral

PA10: Peri<'static, PA10>

PA10 peripheral

PA11: Peri<'static, PA11>

PA11 peripheral

PA12: Peri<'static, PA12>

PA12 peripheral

PA13: Peri<'static, PA13>

PA13 peripheral

PA14: Peri<'static, PA14>

PA14 peripheral

PA15: Peri<'static, PA15>

PA15 peripheral

PB0: Peri<'static, PB0>

PB0 peripheral

PB1: Peri<'static, PB1>

PB1 peripheral

PB2: Peri<'static, PB2>

PB2 peripheral

PB3: Peri<'static, PB3>

PB3 peripheral

PB4: Peri<'static, PB4>

PB4 peripheral

PB5: Peri<'static, PB5>

PB5 peripheral

PB6: Peri<'static, PB6>

PB6 peripheral

PB7: Peri<'static, PB7>

PB7 peripheral

PB8: Peri<'static, PB8>

PB8 peripheral

PB9: Peri<'static, PB9>

PB9 peripheral

PB10: Peri<'static, PB10>

PB10 peripheral

PB12: Peri<'static, PB12>

PB12 peripheral

PB13: Peri<'static, PB13>

PB13 peripheral

PB14: Peri<'static, PB14>

PB14 peripheral

PB15: Peri<'static, PB15>

PB15 peripheral

PC0: Peri<'static, PC0>

PC0 peripheral

PC1: Peri<'static, PC1>

PC1 peripheral

PC2: Peri<'static, PC2>

PC2 peripheral

PC3: Peri<'static, PC3>

PC3 peripheral

PC4: Peri<'static, PC4>

PC4 peripheral

PC5: Peri<'static, PC5>

PC5 peripheral

PC6: Peri<'static, PC6>

PC6 peripheral

PC7: Peri<'static, PC7>

PC7 peripheral

PC8: Peri<'static, PC8>

PC8 peripheral

PC9: Peri<'static, PC9>

PC9 peripheral

PC10: Peri<'static, PC10>

PC10 peripheral

PC11: Peri<'static, PC11>

PC11 peripheral

PC12: Peri<'static, PC12>

PC12 peripheral

PC13: Peri<'static, PC13>

PC13 peripheral

PC14: Peri<'static, PC14>

PC14 peripheral

PC15: Peri<'static, PC15>

PC15 peripheral

PD0: Peri<'static, PD0>

PD0 peripheral

PD1: Peri<'static, PD1>

PD1 peripheral

PD2: Peri<'static, PD2>

PD2 peripheral

PD12: Peri<'static, PD12>

PD12 peripheral

PD13: Peri<'static, PD13>

PD13 peripheral

PD14: Peri<'static, PD14>

PD14 peripheral

PD15: Peri<'static, PD15>

PD15 peripheral

PE0: Peri<'static, PE0>

PE0 peripheral

PE1: Peri<'static, PE1>

PE1 peripheral

PE2: Peri<'static, PE2>

PE2 peripheral

PE3: Peri<'static, PE3>

PE3 peripheral

PE7: Peri<'static, PE7>

PE7 peripheral

PE8: Peri<'static, PE8>

PE8 peripheral

PE9: Peri<'static, PE9>

PE9 peripheral

PE10: Peri<'static, PE10>

PE10 peripheral

PH0: Peri<'static, PH0>

PH0 peripheral

PH1: Peri<'static, PH1>

PH1 peripheral

PH2: Peri<'static, PH2>

PH2 peripheral

PH5: Peri<'static, PH5>

PH5 peripheral

ADC1: Peri<'static, ADC1>

ADC1 peripheral

ADC12_COMMON: Peri<'static, ADC12_COMMON>

ADC12_COMMON peripheral

ADC2: Peri<'static, ADC2>

ADC2 peripheral

ADC3: Peri<'static, ADC3>

ADC3 peripheral

ADC3_COMMON: Peri<'static, ADC3_COMMON>

ADC3_COMMON peripheral

CORDIC: Peri<'static, CORDIC>

CORDIC peripheral

DBGMCU: Peri<'static, DBGMCU>

DBGMCU peripheral

ETH1: Peri<'static, ETH1>

ETH1 peripheral

ETH_SMA: Peri<'static, ETH_SMA>

ETH_SMA peripheral

FDCAN1: Peri<'static, FDCAN1>

FDCAN1 peripheral

FDCAN2: Peri<'static, FDCAN2>

FDCAN2 peripheral

FDCANRAM: Peri<'static, FDCANRAM>

FDCANRAM peripheral

FDCANRAM1: Peri<'static, FDCANRAM1>

FDCANRAM1 peripheral

FDCANRAM2: Peri<'static, FDCANRAM2>

FDCANRAM2 peripheral

FLASH: Peri<'static, FLASH>

FLASH peripheral

I2C1: Peri<'static, I2C1>

I2C1 peripheral

I2C2: Peri<'static, I2C2>

I2C2 peripheral

I3C1: Peri<'static, I3C1>

I3C1 peripheral

LPDMA1: Peri<'static, LPDMA1>

LPDMA1 peripheral

LPDMA2: Peri<'static, LPDMA2>

LPDMA2 peripheral

LPUART1: Peri<'static, LPUART1>

LPUART1 peripheral

PWR: Peri<'static, PWR>

PWR peripheral

MCO1: Peri<'static, MCO1>

MCO1 peripheral

MCO2: Peri<'static, MCO2>

MCO2 peripheral

RCC: Peri<'static, RCC>

RCC peripheral

RNG: Peri<'static, RNG>

RNG peripheral

SPI1: Peri<'static, SPI1>

SPI1 peripheral

SPI2: Peri<'static, SPI2>

SPI2 peripheral

SPI3: Peri<'static, SPI3>

SPI3 peripheral

SYSCFG: Peri<'static, SYSCFG>

SYSCFG peripheral

TIM1: Peri<'static, TIM1>

TIM1 peripheral

TIM15: Peri<'static, TIM15>

TIM15 peripheral

TIM16: Peri<'static, TIM16>

TIM16 peripheral

TIM17: Peri<'static, TIM17>

TIM17 peripheral

TIM2: Peri<'static, TIM2>

TIM2 peripheral

TIM3: Peri<'static, TIM3>

TIM3 peripheral

TIM4: Peri<'static, TIM4>

TIM4 peripheral

TIM5: Peri<'static, TIM5>

TIM5 peripheral

TIM6: Peri<'static, TIM6>

TIM6 peripheral

TIM7: Peri<'static, TIM7>

TIM7 peripheral

TIM8: Peri<'static, TIM8>

TIM8 peripheral

UART4: Peri<'static, UART4>

UART4 peripheral

UART5: Peri<'static, UART5>

UART5 peripheral

UART7: Peri<'static, UART7>

UART7 peripheral

UID: Peri<'static, UID>

UID peripheral

USART1: Peri<'static, USART1>

USART1 peripheral

USART2: Peri<'static, USART2>

USART2 peripheral

USART3: Peri<'static, USART3>

USART3 peripheral

USART6: Peri<'static, USART6>

USART6 peripheral

USB: Peri<'static, USB>

USB peripheral

USBRAM: Peri<'static, USBRAM>

USBRAM peripheral

EXTI0: Peri<'static, EXTI0>

EXTI0 peripheral

EXTI1: Peri<'static, EXTI1>

EXTI1 peripheral

EXTI2: Peri<'static, EXTI2>

EXTI2 peripheral

EXTI3: Peri<'static, EXTI3>

EXTI3 peripheral

EXTI4: Peri<'static, EXTI4>

EXTI4 peripheral

EXTI5: Peri<'static, EXTI5>

EXTI5 peripheral

EXTI6: Peri<'static, EXTI6>

EXTI6 peripheral

EXTI7: Peri<'static, EXTI7>

EXTI7 peripheral

EXTI8: Peri<'static, EXTI8>

EXTI8 peripheral

EXTI9: Peri<'static, EXTI9>

EXTI9 peripheral

EXTI10: Peri<'static, EXTI10>

EXTI10 peripheral

EXTI11: Peri<'static, EXTI11>

EXTI11 peripheral

EXTI12: Peri<'static, EXTI12>

EXTI12 peripheral

EXTI13: Peri<'static, EXTI13>

EXTI13 peripheral

EXTI14: Peri<'static, EXTI14>

EXTI14 peripheral

EXTI15: Peri<'static, EXTI15>

EXTI15 peripheral

LPDMA1_CH0: Peri<'static, LPDMA1_CH0>

LPDMA1_CH0 peripheral

LPDMA1_CH1: Peri<'static, LPDMA1_CH1>

LPDMA1_CH1 peripheral

LPDMA1_CH2: Peri<'static, LPDMA1_CH2>

LPDMA1_CH2 peripheral

LPDMA1_CH3: Peri<'static, LPDMA1_CH3>

LPDMA1_CH3 peripheral

LPDMA1_CH4: Peri<'static, LPDMA1_CH4>

LPDMA1_CH4 peripheral

LPDMA1_CH5: Peri<'static, LPDMA1_CH5>

LPDMA1_CH5 peripheral

LPDMA1_CH6: Peri<'static, LPDMA1_CH6>

LPDMA1_CH6 peripheral

LPDMA1_CH7: Peri<'static, LPDMA1_CH7>

LPDMA1_CH7 peripheral

LPDMA2_CH0: Peri<'static, LPDMA2_CH0>

LPDMA2_CH0 peripheral

LPDMA2_CH1: Peri<'static, LPDMA2_CH1>

LPDMA2_CH1 peripheral

LPDMA2_CH2: Peri<'static, LPDMA2_CH2>

LPDMA2_CH2 peripheral

LPDMA2_CH3: Peri<'static, LPDMA2_CH3>

LPDMA2_CH3 peripheral

LPDMA2_CH4: Peri<'static, LPDMA2_CH4>

LPDMA2_CH4 peripheral

LPDMA2_CH5: Peri<'static, LPDMA2_CH5>

LPDMA2_CH5 peripheral

LPDMA2_CH6: Peri<'static, LPDMA2_CH6>

LPDMA2_CH6 peripheral

LPDMA2_CH7: Peri<'static, LPDMA2_CH7>

LPDMA2_CH7 peripheral

Implementations

Source

impl Peripherals

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that youโ€™re only using one instance of this type at a time.